==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkPKdTree.java <==
// java wrapper for vtkPKdTree object
//

package vtk;
import vtk.*;

public class vtkPKdTree extends vtkKdTree
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void BuildLocator_2();
  public void BuildLocator()
    { BuildLocator_2(); }

  private native int GetTotalNumberOfCells_3();
  public int GetTotalNumberOfCells()
    { return GetTotalNumberOfCells_3(); }

  private native int CreateProcessCellCountData_4();
  public int CreateProcessCellCountData()
    { return CreateProcessCellCountData_4(); }

  private native int CreateGlobalDataArrayBounds_5();
  public int CreateGlobalDataArrayBounds()
    { return CreateGlobalDataArrayBounds_5(); }

  private native void SetController_6(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_6(id0); }

  private native long GetController_7();
  public vtkMultiProcessController GetController() {
    long temp = GetController_7();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetRegionAssignment_8();
  public int GetRegionAssignment()
    { return GetRegionAssignment_8(); }

  private native int AssignRegionsRoundRobin_9();
  public int AssignRegionsRoundRobin()
    { return AssignRegionsRoundRobin_9(); }

  private native int AssignRegionsContiguous_10();
  public int AssignRegionsContiguous()
    { return AssignRegionsContiguous_10(); }

  private native int GetRegionAssignmentMapLength_11();
  public int GetRegionAssignmentMapLength()
    { return GetRegionAssignmentMapLength_11(); }

  private native int GetRegionAssignmentList_12(int id0,vtkIntArray id1);
  public int GetRegionAssignmentList(int id0,vtkIntArray id1)
    { return GetRegionAssignmentList_12(id0,id1); }

  private native void GetAllProcessesBorderingOnPoint_13(double id0,double id1,double id2,vtkIntArray id3);
  public void GetAllProcessesBorderingOnPoint(double id0,double id1,double id2,vtkIntArray id3)
    { GetAllProcessesBorderingOnPoint_13(id0,id1,id2,id3); }

  private native int GetProcessAssignedToRegion_14(int id0);
  public int GetProcessAssignedToRegion(int id0)
    { return GetProcessAssignedToRegion_14(id0); }

  private native int HasData_15(int id0,int id1);
  public int HasData(int id0,int id1)
    { return HasData_15(id0,id1); }

  private native int GetProcessCellCountForRegion_16(int id0,int id1);
  public int GetProcessCellCountForRegion(int id0,int id1)
    { return GetProcessCellCountForRegion_16(id0,id1); }

  private native int GetTotalProcessesInRegion_17(int id0);
  public int GetTotalProcessesInRegion(int id0)
    { return GetTotalProcessesInRegion_17(id0); }

  private native int GetProcessListForRegion_18(int id0,vtkIntArray id1);
  public int GetProcessListForRegion(int id0,vtkIntArray id1)
    { return GetProcessListForRegion_18(id0,id1); }

  private native int GetTotalRegionsForProcess_19(int id0);
  public int GetTotalRegionsForProcess(int id0)
    { return GetTotalRegionsForProcess_19(id0); }

  private native int GetRegionListForProcess_20(int id0,vtkIntArray id1);
  public int GetRegionListForProcess(int id0,vtkIntArray id1)
    { return GetRegionListForProcess_20(id0,id1); }

  private native int GetCellListsForProcessRegions_21(int id0,int id1,vtkIdList id2,vtkIdList id3);
  public int GetCellListsForProcessRegions(int id0,int id1,vtkIdList id2,vtkIdList id3)
    { return GetCellListsForProcessRegions_21(id0,id1,id2,id3); }

  private native int GetCellListsForProcessRegions_22(int id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3);
  public int GetCellListsForProcessRegions(int id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3)
    { return GetCellListsForProcessRegions_22(id0,id1,id2,id3); }

  private native int GetCellListsForProcessRegions_23(int id0,vtkIdList id1,vtkIdList id2);
  public int GetCellListsForProcessRegions(int id0,vtkIdList id1,vtkIdList id2)
    { return GetCellListsForProcessRegions_23(id0,id1,id2); }

  private native int ViewOrderAllProcessesInDirection_24(double id0[],vtkIntArray id1);
  public int ViewOrderAllProcessesInDirection(double id0[],vtkIntArray id1)
    { return ViewOrderAllProcessesInDirection_24(id0,id1); }

  private native int ViewOrderAllProcessesFromPosition_25(double id0[],vtkIntArray id1);
  public int ViewOrderAllProcessesFromPosition(double id0[],vtkIntArray id1)
    { return ViewOrderAllProcessesFromPosition_25(id0,id1); }

  private native int GetCellArrayGlobalRange_26(String id0,double id1[]);
  public int GetCellArrayGlobalRange(String id0,double id1[])
    { return GetCellArrayGlobalRange_26(id0,id1); }

  private native int GetPointArrayGlobalRange_27(String id0,double id1[]);
  public int GetPointArrayGlobalRange(String id0,double id1[])
    { return GetPointArrayGlobalRange_27(id0,id1); }

  private native int GetCellArrayGlobalRange_28(int id0,double id1[]);
  public int GetCellArrayGlobalRange(int id0,double id1[])
    { return GetCellArrayGlobalRange_28(id0,id1); }

  private native int GetPointArrayGlobalRange_29(int id0,double id1[]);
  public int GetPointArrayGlobalRange(int id0,double id1[])
    { return GetPointArrayGlobalRange_29(id0,id1); }

  public vtkPKdTree() { super(); }

  public vtkPKdTree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-aarch64.pkg.tar.xz: vtk/vtkPKdTree.java <==
// java wrapper for vtkPKdTree object
//

package vtk;
import vtk.*;

public class vtkPKdTree extends vtkKdTree
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void BuildLocator_2();
  public void BuildLocator()
    { BuildLocator_2(); }

  private native int GetTotalNumberOfCells_3();
  public int GetTotalNumberOfCells()
    { return GetTotalNumberOfCells_3(); }

  private native int CreateProcessCellCountData_4();
  public int CreateProcessCellCountData()
    { return CreateProcessCellCountData_4(); }

  private native int CreateGlobalDataArrayBounds_5();
  public int CreateGlobalDataArrayBounds()
    { return CreateGlobalDataArrayBounds_5(); }

  private native void SetController_6(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_6(id0); }

  private native long GetController_7();
  public vtkMultiProcessController GetController() {
    long temp = GetController_7();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetRegionAssignment_8();
  public int GetRegionAssignment()
    { return GetRegionAssignment_8(); }

  private native int AssignRegionsRoundRobin_9();
  public int AssignRegionsRoundRobin()
    { return AssignRegionsRoundRobin_9(); }

  private native int AssignRegionsContiguous_10();
  public int AssignRegionsContiguous()
    { return AssignRegionsContiguous_10(); }

  private native int GetRegionAssignmentMapLength_11();
  public int GetRegionAssignmentMapLength()
    { return GetRegionAssignmentMapLength_11(); }

  private native int GetRegionAssignmentList_12(int id0,vtkIntArray id1);
  public int GetRegionAssignmentList(int id0,vtkIntArray id1)
    { return GetRegionAssignmentList_12(id0,id1); }

  private native void GetAllProcessesBorderingOnPoint_13(double id0,double id1,double id2,vtkIntArray id3);
  public void GetAllProcessesBorderingOnPoint(double id0,double id1,double id2,vtkIntArray id3)
    { GetAllProcessesBorderingOnPoint_13(id0,id1,id2,id3); }

  private native int GetProcessAssignedToRegion_14(int id0);
  public int GetProcessAssignedToRegion(int id0)
    { return GetProcessAssignedToRegion_14(id0); }

  private native int HasData_15(int id0,int id1);
  public int HasData(int id0,int id1)
    { return HasData_15(id0,id1); }

  private native int GetProcessCellCountForRegion_16(int id0,int id1);
  public int GetProcessCellCountForRegion(int id0,int id1)
    { return GetProcessCellCountForRegion_16(id0,id1); }

  private native int GetTotalProcessesInRegion_17(int id0);
  public int GetTotalProcessesInRegion(int id0)
    { return GetTotalProcessesInRegion_17(id0); }

  private native int GetProcessListForRegion_18(int id0,vtkIntArray id1);
  public int GetProcessListForRegion(int id0,vtkIntArray id1)
    { return GetProcessListForRegion_18(id0,id1); }

  private native int GetTotalRegionsForProcess_19(int id0);
  public int GetTotalRegionsForProcess(int id0)
    { return GetTotalRegionsForProcess_19(id0); }

  private native int GetRegionListForProcess_20(int id0,vtkIntArray id1);
  public int GetRegionListForProcess(int id0,vtkIntArray id1)
    { return GetRegionListForProcess_20(id0,id1); }

  private native int GetCellListsForProcessRegions_21(int id0,int id1,vtkIdList id2,vtkIdList id3);
  public int GetCellListsForProcessRegions(int id0,int id1,vtkIdList id2,vtkIdList id3)
    { return GetCellListsForProcessRegions_21(id0,id1,id2,id3); }

  private native int GetCellListsForProcessRegions_22(int id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3);
  public int GetCellListsForProcessRegions(int id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3)
    { return GetCellListsForProcessRegions_22(id0,id1,id2,id3); }

  private native int GetCellListsForProcessRegions_23(int id0,vtkIdList id1,vtkIdList id2);
  public int GetCellListsForProcessRegions(int id0,vtkIdList id1,vtkIdList id2)
    { return GetCellListsForProcessRegions_23(id0,id1,id2); }

  private native int ViewOrderAllProcessesInDirection_24(double id0[],vtkIntArray id1);
  public int ViewOrderAllProcessesInDirection(double id0[],vtkIntArray id1)
    { return ViewOrderAllProcessesInDirection_24(id0,id1); }

  private native int ViewOrderAllProcessesFromPosition_25(double id0[],vtkIntArray id1);
  public int ViewOrderAllProcessesFromPosition(double id0[],vtkIntArray id1)
    { return ViewOrderAllProcessesFromPosition_25(id0,id1); }

  private native int GetCellArrayGlobalRange_26(String id0,double id1[]);
  public int GetCellArrayGlobalRange(String id0,double id1[])
    { return GetCellArrayGlobalRange_26(id0,id1); }

  private native int GetPointArrayGlobalRange_27(String id0,double id1[]);
  public int GetPointArrayGlobalRange(String id0,double id1[])
    { return GetPointArrayGlobalRange_27(id0,id1); }

  private native int GetCellArrayGlobalRange_28(int id0,double id1[]);
  public int GetCellArrayGlobalRange(int id0,double id1[])
    { return GetCellArrayGlobalRange_28(id0,id1); }

  private native int GetPointArrayGlobalRange_29(int id0,double id1[]);
  public int GetPointArrayGlobalRange(int id0,double id1[])
    { return GetPointArrayGlobalRange_29(id0,id1); }

  public vtkPKdTree() { super(); }

  public vtkPKdTree(long id) { super(id); }
  public native long   VTKInit();

}
